@@ -4,9 +4,7 @@
  * Gnome Chemistry Utils
  * chemistry/xml-utils.cc 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,6 +24,10 @@
 
 #include "xml-utils.h"
 #include <string.h>
+#include <set>
+#include <string>
+
+using namespace std;
 
 xmlNodePtr FindNodeByNameAndId (xmlNodePtr node, const char* name, const char* id)
 {
@@ -171,7 +173,7 @@ bool ReadRadius (xmlNodePtr node, GcuAtomicRadius& radius)
 		xmlFree (tmp);
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "scale");
 	if (tmp) {
-		radius.scale = g_strdup (tmp);
+		radius.scale = GetStaticScale (tmp);
 		xmlFree (tmp);
 	} else
 		radius.scale = NULL;
@@ -267,3 +269,19 @@ bool WriteRadius (xmlDocPtr xml, xmlNodePtr node, const GcuAtomicRadius& radius)
 		xmlNewProp (child, (xmlChar*) "spin", (xmlChar*)((radius.spin == GCU_LOW_SPIN)? "low": "high"));
 	return true;
 }
+
+// we must have static strings 
+static set <string> ScaleNames;
+
+char const *GetStaticScale (char *buf)
+{
+	set <string>::iterator i = ScaleNames.find (buf);
+	if (i == ScaleNames.end ()) {
+		std::pair<set <string>::iterator,bool> res = ScaleNames.insert (buf);
+		if (res.second)
+			return (*res.first).c_str ();
+		else
+			return NULL;
+	}
+	return (*i).c_str ();
+}
