@@ -4,24 +4,22 @@
  * Gnome Chemistry Utils
  * xml-utils.h
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 
@@ -127,4 +125,15 @@ Save a radius as an XML node added to the children of node. This radius can then
 @return true on success and false on failure.
 */
 bool WriteRadius (xmlDocPtr xml, xmlNodePtr node, const GcuAtomicRadius& radius);
+
+/*!
+@param buf: a string to convert to a static instance.
+
+This function is used to replace a dynamically allocated string by a static instance. It
+works managing a set of string instances. It is used for scale names (as for radii and
+electronegativity), hence its name.
+
+@return a static version of buf or NULL if a new static string could not be created.
+*/
+char const *GetStaticScale (char *buf);
 #endif	// GCU_XML_UTILS_H
